# Contributing to Kaggler

We welcome community contributors.

When contributing to Kaggler, please follow the [PEP8 style guide](https://www.python.org/dev/peps/pep-0008/).

In your PR, please include:
- Changes made
- Links to related issues/PRs
- Dependencies
- References

Please add `jeongyoonlee` as a reviewer.
